summaryrefslogtreecommitdiffstats
path: root/host/include
diff options
context:
space:
mode:
authorJosh Blum <josh@joshknows.com>2010-03-30 14:12:11 +0000
committerJosh Blum <josh@joshknows.com>2010-03-30 14:12:11 +0000
commitc81a975766a8831cab1e3123af94b4fe4a09d9bc (patch)
tree7b3185f8829495a023344b162e4f77122705847d /host/include
parentf94fa1e464c9e2a87274c991dc6461f7f4c956d8 (diff)
downloaduhd-c81a975766a8831cab1e3123af94b4fe4a09d9bc.tar.gz
uhd-c81a975766a8831cab1e3123af94b4fe4a09d9bc.tar.bz2
uhd-c81a975766a8831cab1e3123af94b4fe4a09d9bc.zip
compiling with master merge, renamed usrp1e to usrp_e
Diffstat (limited to 'host/include')
-rw-r--r--host/include/uhd/usrp/CMakeLists.txt2
-rw-r--r--host/include/uhd/usrp/usrp_e.hpp (renamed from host/include/uhd/usrp/usrp1e.hpp)20
2 files changed, 11 insertions, 11 deletions
diff --git a/host/include/uhd/usrp/CMakeLists.txt b/host/include/uhd/usrp/CMakeLists.txt
index bab01fdeb..b9be370bd 100644
--- a/host/include/uhd/usrp/CMakeLists.txt
+++ b/host/include/uhd/usrp/CMakeLists.txt
@@ -21,7 +21,7 @@ INSTALL(FILES
dboard_id.hpp
dboard_interface.hpp
dboard_manager.hpp
- usrp1e.hpp
+ usrp_e.hpp
usrp2.hpp
DESTINATION ${INCLUDE_DIR}/uhd/usrp
)
diff --git a/host/include/uhd/usrp/usrp1e.hpp b/host/include/uhd/usrp/usrp_e.hpp
index 75da58453..557058261 100644
--- a/host/include/uhd/usrp/usrp1e.hpp
+++ b/host/include/uhd/usrp/usrp_e.hpp
@@ -15,8 +15,8 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//
-#ifndef INCLUDED_UHD_USRP_USRP1E_HPP
-#define INCLUDED_UHD_USRP_USRP1E_HPP
+#ifndef INCLUDED_UHD_USRP_USRP_E_HPP
+#define INCLUDED_UHD_USRP_USRP_E_HPP
#include <uhd/config.hpp>
#include <uhd/device.hpp>
@@ -24,21 +24,21 @@
namespace uhd{ namespace usrp{
/*!
- * The usrp1e device class.
+ * The USRP-Embedded device class.
*/
-class UHD_API usrp1e : public device{
+class UHD_API usrp_e : public device{
public:
/*!
* Find usrp1e devices on the system via the device node.
* \param hint a device addr with the usrp1e address filled in
* \return a vector of device addresses for all usrp1es found
*/
static device_addrs_t find(const device_addr_t &hint);
/*!
* Make a usrp1e from a device address.
* \param addr the device address
* \return a device sptr to a new usrp1e
*/
static device::sptr make(const device_addr_t &addr);
@@ -51,4 +51,4 @@ public:
}} //namespace
-#endif /* INCLUDED_UHD_USRP_USRP1E_HPP */
+#endif /* INCLUDED_UHD_USRP_USRP_E_HPP */
@@ -24,21 +24,21 @@
public:
/*!
- * Find usrp1e devices on the system via the device node.
- * \param hint a device addr with the usrp1e address filled in
- * \return a vector of device addresses for all usrp1es found
+ * Find usrp_e devices on the system via the device node.
+ * \param hint a device addr with the usrp_e address filled in
+ * \return a vector of device addresses for all usrp-e's found
*/
static device_addrs_t find(const device_addr_t &hint);
@@ -24,21 +24,21 @@
static device_addrs_t find(const device_addr_t &hint);
/*!
- * Make a usrp1e from a device address.
+ * Make a usrp_e from a device address.
* \param addr the device address
@@ -24,21 +24,21 @@
* \param addr the device address
- * \return a device sptr to a new usrp1e
+ * \return a device sptr to a new usrp_e
*/
static device::sptr make(const device_addr_t &addr);